==> qtjambi-qml-debuginfo-macos-6.5.8.jar: sources/QtJambiQml/QJSValueIterator_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qjsvalueiterator.h>
#include <QtCore/QVariant>
#include <QtQml/qjsvalue.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QJSValueIterator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QJSValueIterator")
    QJSValueIterator *_ptr = reinterpret_cast<QJSValueIterator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QJSValueIterator(QJSValue)
void __qt_construct_QJSValueIterator_cref_QJSValue(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QJSValueIterator(QJSValue)")
    jobject value0 = __java_arguments[0].l;
    const QJSValue& __qt_value0 = qtjambi_cast<const QJSValue&>(__jni_env, value0);
    QJSValueIterator *__qt_this = new(__qtjambi_ptr) QJSValueIterator(__qt_value0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QJSValueIterator::QJSValueIterator(QJSValue)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_initialize_1native__Lio_qt_qml_QJSValueIterator_2Lio_qt_qml_QJSValue_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject value0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSValueIterator::QJSValueIterator(QJSValue)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = value0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QJSValueIterator_cref_QJSValue, sizeof(QJSValueIterator), typeid(QJSValueIterator), 0, false, &deleter_QJSValueIterator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QJSValueIterator
void __qt_destruct_QJSValueIterator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QJSValueIterator")
    reinterpret_cast<QJSValueIterator*>(ptr)->~QJSValueIterator();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QJSValueIterator::hasNext()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_hasNext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QJSValueIterator *__qt_this = QtJambiAPI::objectFromNativeId<QJSValueIterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJSValueIterator::hasNext()const", __this_nativeId)
        __java_return_value = __qt_this->hasNext();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSValueIterator::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QJSValueIterator *__qt_this = QtJambiAPI::objectFromNativeId<QJSValueIterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJSValueIterator::name()const", __this_nativeId)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSValueIterator::next()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_next_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QJSValueIterator *__qt_this = QtJambiAPI::objectFromNativeId<QJSValueIterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJSValueIterator::next()", __this_nativeId)
        __java_return_value = __qt_this->next();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSValueIterator::value()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QJSValueIterator *__qt_this = QtJambiAPI::objectFromNativeId<QJSValueIterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJSValueIterator::value()const", __this_nativeId)
        QJSValue __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QJSValueIterator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QJSValueIterator>("QJSValueIterator", "io/qt/qml/QJSValueIterator");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QJSValueIterator, {
        ConstructorInfo(&__qt_construct_QJSValueIterator_cref_QJSValue, "Lio/qt/qml/QJSValue;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QJSValueIterator);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.6.1.jar: sources/QtJambiQml/QJSValueIterator_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qjsvalueiterator.h>
#include <QtCore/QVariant>
#include <QtQml/qjsvalue.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QJSValueIterator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QJSValueIterator")
    QJSValueIterator *_ptr = reinterpret_cast<QJSValueIterator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QJSValueIterator(QJSValue)
void __qt_construct_QJSValueIterator_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QJSValueIterator(QJSValue)")
    jobject value0 = __java_arguments[0].l;
    const QJSValue& __qt_value0 = qtjambi_cast<const QJSValue& >(__jni_env, value0);
    QJSValueIterator *__qt_this = new(__qtjambi_ptr) QJSValueIterator(__qt_value0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QJSValueIterator
void __qt_destruct_QJSValueIterator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QJSValueIterator")
    reinterpret_cast<QJSValueIterator*>(ptr)->~QJSValueIterator();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QJSValueIterator::QJSValueIterator(QJSValue)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_initialize_1native__Lio_qt_qml_QJSValueIterator_2Lio_qt_qml_QJSValue_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject value0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSValueIterator::QJSValueIterator(QJSValue)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = value0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QJSValueIterator_0, sizeof(QJSValueIterator), typeid(QJSValueIterator), false, &deleter_QJSValueIterator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QJSValueIterator::hasNext()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_hasNext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QJSValueIterator *__qt_this = QtJambiAPI::objectFromNativeId<QJSValueIterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJSValueIterator::hasNext()const", __qt_this)
        __java_return_value = __qt_this->hasNext();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSValueIterator::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QJSValueIterator *__qt_this = QtJambiAPI::objectFromNativeId<QJSValueIterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJSValueIterator::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSValueIterator::next()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_next_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QJSValueIterator *__qt_this = QtJambiAPI::objectFromNativeId<QJSValueIterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJSValueIterator::next()", __qt_this)
        __java_return_value = __qt_this->next();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSValueIterator::value()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSValueIterator_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QJSValueIterator *__qt_this = QtJambiAPI::objectFromNativeId<QJSValueIterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJSValueIterator::value()const", __qt_this)
        QJSValue __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QJSValueIterator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QJSValueIterator>("QJSValueIterator", "io/qt/qml/QJSValueIterator");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QJSValueIterator, {
        ConstructorInfo(&__qt_construct_QJSValueIterator_0, "Lio/qt/qml/QJSValue;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QJSValueIterator);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
